package websocket

import (
	"encoding/json"
	"git.smsvc.net/pomodoro/GoTomato/internal/pomodoro"
	"git.smsvc.net/pomodoro/GoTomato/internal/shared"
	"git.smsvc.net/pomodoro/GoTomato/pkg/models"
	"github.com/gorilla/websocket"
	"log"
)

var pomodoroConfig = shared.DefaultPomodoroConfig

// handleClientCommands listens for commands from WebSocket clients
func handleClientCommands(ws *websocket.Conn) {
	for {
		var clientCommand models.ClientCommand

		_, message, err := ws.ReadMessage()
		if err != nil {
			log.Printf("Client disconnected: %v", err)
			delete(Clients, ws)
			break
		}

		// Handle incoming commands
		err = json.Unmarshal(message, &clientCommand)
		if err != nil {
			log.Printf("Error unmarshalling command: %v", err)
			continue
		}

		// Process the command if pomodoro password matches
		if clientCommand.Password == shared.PomodoroPassword {
			switch clientCommand.Command {
			case "start":
				if !pomodoro.IsPomodoroOngoing() {
					if clientCommand.Config != shared.UnsetPomodoroConfig {
						pomodoroConfig = clientCommand.Config
					}
					go pomodoro.RunPomodoro(pomodoroConfig) // Start the timer with the list of clients
				}
			case "stop":
				if pomodoro.IsPomodoroOngoing() {
					pomodoro.ResetPomodoro() // Reset Pomodoro
				}
			case "pause":
				if pomodoro.IsPomodoroOngoing() && !pomodoro.IsPomodoroPaused() {
					pomodoro.PausePomodoro() // Pause the timer
				}
			case "resume":
				if pomodoro.IsPomodoroOngoing() && pomodoro.IsPomodoroPaused() {
					pomodoro.ResumePomodoro() // Resume the timer
				}
			}
		}

	}
}
